--Initialize local variables--
local version="1.00"
local isMount=false
local ModelPique_ItemId_Table={}
local ModelPique_SpellId_Table={}
local ModelPique_BattlePetId_Table={}

--Global to local variables--
local pairs = pairs
local strmatch = string.match
local tonumber = tonumber
local format = string.format

--Functions--
local function ModelPique_ShowModel(modelName, displayID)
	if not displayID then return end
	local frame, model
	if ( SideDressUpFrame.parentFrame and SideDressUpFrame.parentFrame:IsShown() ) then
		frame, model = SideDressUpFrame, SideDressUpModel
		isMount = false
	else
		frame, model = DressUpFrame, DressUpModel
		isMount=true
		DressUpFrameTitleText:SetText(format("%s%s","Model Pique v",version))
		DressUpFrameDescriptionText:SetText(modelName)
		DressUpFrameDescriptionText:SetPoint("CENTER", "DressUpFrameTitleText", "BOTTOM", "0", "-22")
		DressUpFrameDescriptionText:SetFontObject(GameFontNormal)
	end
	if ( not frame:IsShown() or frame.mode ~= "battlepet" ) then
		SetDressUpBackground(frame, "Pet")
		ShowUIPanel(frame)	
	end
	if frame == DressUpFrame then
		SetPortraitTexture(DressUpFramePortrait, displayID)
	end
	frame.mode = "battlepet"
	frame.ResetButton:Hide()
	if ( displayID and displayID ~= 0 ) then
		model:SetDisplayInfo(displayID)
	else
		model:SetCreature(creatureID)
	end
end

local function ModelPique_GetDisplayID(link)
	if not link then return end
	local item=tonumber(strmatch(link,"item:(%d+)"))
	local spell=tonumber(strmatch(link,"spell:(%d+)"))
	local battlePet=tonumber(strmatch(link,"battlepet:(%d+)"))
	if item then
		local compare = ModelPique_ItemId_Table[item]
		if compare then 
			for k,v in pairs(ModelPique_SpellId_Table) do
				if v == compare and k ~= item then
					link = k
				end
			end
		end
	end
	local modelName=GetSpellInfo(link) or strmatch(link,"%[(.*)%]")
	return modelName, ModelPique_ItemId_Table[item] or ModelPique_SpellId_Table[spell] or ModelPique_BattlePetId_Table[battlePet]
end

hooksecurefunc("DressUpItemLink",function(link)
	if not IsDressableItem(link) then
		ModelPique_ShowModel(ModelPique_GetDisplayID(link))
	else
		if isMount then
			DressUpFrameTitleText:SetText(DRESSUP_FRAME)
			DressUpFrameDescriptionText:SetText(DRESSUP_FRAME_INSTRUCTIONS)
			DressUpFrameDescriptionText:SetPoint("CENTER", "DressUpFrameTitleText", "BOTTOM", "10", "-22")
			DressUpFrameDescriptionText:SetFontObject("GameFontNormalSmall")
			SetPortraitTexture(DressUpFramePortrait, "player")
			local _, fileName = UnitRace("player")
            		SetDressUpBackground(DressUpFrame, fileName)
			DressUpModel:SetUnit("player")
			DressUpModel:TryOn(link)
		end
		isMount = false
	end
end)

--Item Data table--
ModelPique_ItemId_Table={
------------------------------------------
--**************************************--
--*************** MOUNTS ***************--
--**************************************--
------------------------------------------
--1.11.1 and earlier
[18796]=14573,
[21176]=15676,
[12302]=9695,
[12303]=9991,
[12330]=2326,
[12351]=1166,
[12353]=2410,
[12354]=2408,
[13086]=10426,
[13317]=6471,
[13326]=9474,
[13327]=10666,
[13328]=2784,
[13329]=2787,
[13334]=10720,
[13335]=10718,
[15292]=12245,
[15293]=12242,
[18766]=14331,
[18767]=14332,
[18772]=14374,
[18773]=14376,
[18774]=14377,
[18776]=14582,
[18777]=14583,
[18778]=14338,
[18785]=14346,
[18786]=14347,
[18787]=14576,
[18788]=14339,
[18789]=14344,
[18790]=14342,
[18791]=10721,
[18793]=14349,
[18794]=14578,
[18795]=14579,
[8586]=6469,
[18797]=14575,
[18798]=14574,
[18902]=14632,
[19029]=14776,
[19030]=14777,
[19872]=15289,
[19902]=15290,
[21218]=15672,
[21321]=15681,
[21323]=15679,
[21324]=15680,
[8591]=6472,
[1132]=247,
[2414]=2409,
[5655]=2405,
[5656]=2404,
[5665]=2327,
[5668]=2328,
[5864]=2736,
[5872]=2785,
[5873]=2786,
[8563]=9473,
[8588]=4806,
[2411]=2402,
[8592]=6473,
[8595]=6569,
[8629]=6448,
[8631]=6080,
[8632]=6444,
[13321]=10661,
[13322]=9476,
[13331]=10670,
[13332]=10671,
[13333]=10672,
[15277]=12246,
[15290]=11641,
--2.0
[23720]=17158,
--2.0.1
[25477]=17719,
[25532]=17722,
[25533]=17721,
[25531]=17720,
[25470]=17697,
[25471]=17694,
[25472]=17696,
[25474]=17699,
[25475]=17700,
[25476]=17701,
[28915]=21074,
[28936]=18697,
[29102]=19375,
[29103]=19377,
[29104]=19378,
[29105]=19376,
[29223]=19484,
[29224]=19482,
[29227]=19375,
[29228]=19303,
[29229]=19378,
[29230]=19376,
[29231]=19377,
[29465]=14372,
[29466]=14348,
[29467]=14577,
[29468]=14337,
[29469]=14334,
[29470]=10719,
[29471]=14330,
[29472]=14388,
[29745]=19871,
[29746]=19873,
[29747]=19872,
[30480]=19250,
[31829]=21073,
[31830]=21073,
[31831]=21075,
[31832]=21075,
[31833]=21077,
[31834]=21077,
[31835]=21076,
[31836]=21076,
[28481]=17063,
[28927]=18696,
[29220]=19480,
[29221]=19478,
[29222]=19479,
[29743]=19870,
[29744]=19869,
--2.1
[32319]=21156,
[25473]=17759,
[25528]=17703,
[25529]=17717,
[32314]=21152,
[32316]=21155,
[32317]=21158,
[32318]=21157,
[25527]=17718,
[32857]=21520,
[32858]=21521,
[32859]=21525,
[32860]=21523,
[32861]=21522,
[32862]=21524,
[32768]=21473,
--2.1.1
[32458]=17890,
--2.1.2
[30609]=20344,
--2.2
[33977]=22350,
[33976]=22265,
--2.2.2
[33182]=21939,
[33184]=21939,
[33176]=21939,
--33183(no id, no spell)
--2.3
[25596]=17890,
[33809]=22464,
[33999]=22473,
[34061]=22720,
[34092]=22620,
[34060]=22719,
[34129]=20359,
--2.4
[35513]=19483,
[35906]=23928,
--2.4.2
[37676]=24725,
--2.4.3
[43516]=27507,
[37719]=24745,
[37828]=24757,
[37012]=25159,
[43599]=27567,
[37011]=21939,
[37750]=24758,
[39476]=24758,
--3.0.1
[41508]=25871,
[40775]=28108,
--3.0.2
[44413]=25870,
[44221]=17697,
[44229]=17699,
[44168]=28045,
[43952]=27785,
[43954]=27796,
[43955]=25835,
[43951]=25833,
[44151]=22720,
[43953]=25832,
[44178]=25836,
[44558]=28060,
[44689]=27913,
[44690]=27914,
[43986]=25831,
[44554]=28082,
[44223]=27818,
[43956]=27247,
[43961]=27242,
[43962]=28428,
[44077]=27245,
[44080]=27246,
[44086]=27239,
[43958]=27248,
[44224]=27819,
[44225]=27820,
[44226]=27821,
[44230]=27243,
[44231]=27244,
[44234]=27238,
[44235]=27237,
--3.0.3
[44160]=28044,
[44707]=28053,
[43959]=27241,
--3.0.8
[44175]=28042,
--3.0.9
[44164]=28040,
[44083]=27240,
--3.1
[46109]=29161,
[44843]=27525,
[45693]=28890,
[45725]=22471,
[44842]=28402,
[45125]=22903,
[45586]=29258,
[45589]=28571,
[45590]=29255,
[45591]=29256,
[45592]=29259,
[45593]=29261,
[45595]=29260,
[45596]=29262,
[45597]=29257,
[46101]=10718,
[46099]=207,
[46100]=12241,
[46308]=29130,
--3.1.1
[46171]=25593,
--3.1.2
[45802]=28954,
[46752]=29043,
[46744]=14333,
[46745]=28606,
[46746]=28605,
[46743]=14343,
[46748]=28612,
[46749]=14335,
[46750]=28556,
[46751]=28607,
[46747]=14375,
--3.1.3
[45801]=28953,
--3.2
[44177]=28043,
[46813]=22474,
[46814]=29696,
[49286]=23647,
[46708]=25511,
[49285]=23656,
[46102]=29102,
[46815]=28888,
[46816]=28889,
[47101]=29754,
[47179]=28919,
[47180]=28918,
[49044]=29284,
[49096]=29937,
[49098]=29938,
[49282]=25335,
[49284]=21974,
[49290]=29344,
[47100]=29755,
[49283]=21973,
--3.2.2
[49636]=30346,
[49046]=29283,
[49288]=30141,
[49289]=30518,
--3.3
[50818]=31007,
--3.3.2
[51954]=31156,
[50250]=30989,
--3.3.3
[47840]=29794,
[51955]=31154,
[54797]=28063,
[54069]=31803,
[54860]=31992,
[52200]=25279,
[54811]=31958,
--3.3.5
[54068]=31721,
--4.0.1
[65891]=35750,
[63043]=35751,
[62900]=35551,
[62901]=35757,
[63039]=35754,
[63040]=35553,
[63041]=35755,
[63042]=35740,
[50435]=31047,
[63125]=37145,
[64998]=37160,
[64999]=37159,
[65356]=35754,
[63044]=35136,
[63045]=35134,
[63046]=35135,
[64883]=15672,
--4.0.3
[67151]=34955,
[54465]=34956,
[68008]=37231,
[60954]=34410,
[62462]=35250,
[62298]=36213,
[67107]=37138,
[62461]=35249,
--4.1
[69747]=38261,
[69213]=38018,
[69224]=38031,
[68825]=37800,
[68823]=14341,
[68824]=37799,
[69228]=38048,
[69846]=38260,
--4.2
[69230]=38046,
[71339]=38756,
[70909]=38668,
[70910]=38607,
[71665]=38783,
--4.3
[77067]=39561,
[77069]=39563,
[78919]=39229,
[77068]=39562,
[71954]=38755,
[74269]=31803,
[76889]=39546,
[76902]=39547,
[73839]=39095,
[71718]=17011,
[72140]=1281,
[72145]=16992,
[72146]=1961,
[72575]=37204,
[73766]=39060,
[76755]=39530,
[78924]=40029,
[73838]=39096,
--4.3.2
[79771]=40568,
--5.0.1
[83088]=42502,
[79802]=40590,
[82453]=42185,
[84101]=42703,
[85429]=41991,
[85430]=41989,
[87768]=41990,
[87769]=41592,
[87771]=43689,
[87773]=43692,
[87774]=43693,
[87777]=46087,
[87781]=43704,
[87782]=43705,
[87783]=43706,
[87788]=43711,
[87789]=43712,
[89154]=44633,
[89304]=43686,
[89305]=44759,
[89306]=44757,
[89307]=43900,
[89362]=44807,
[89390]=44837,
[89391]=44836,
[89783]=45264,
[83087]=42499,
[81354]=41711,
[83089]=42501,
[83090]=42500,
[81559]=41903,
[85666]=43562,
[89785]=45271,
[85262]=43090,
[83086]=42498,
[87250]=43637,
[87251]=43638,
[89363]=44808,
[82811]=42352,
[87801]=43722,
[87802]=43723,
[87803]=43724,
[87804]=43725,
[87805]=43726,
[85870]=43254,
[82765]=42250,
[87795]=43717,
[87796]=43718,
[87797]=43719,
[87799]=43720,
[87800]=43721,
[89682]=44635,
[89697]=45163,
[89770]=45242,
--5.0.4
[90655]=45797,
[90711]=45520,
[90712]=45522,
[90710]=45521,
[91010]=42352,
[91011]=43723,
[91012]=43722,
[91013]=43724,
[91014]=43725,
[91015]=43726,
[91004]=42250,
[91005]=43719,
[91006]=43720,
[91007]=43721,
[91008]=43717,
[91009]=43718,
--5.0.5
[85785]=38757,
--5.1
[93168]=46929,
[93169]=46930,
[93385]=47166,
[93386]=47165,
[91802]=42147,
[92724]=46729,
--5.2
[93666]=47238,
[95057]=47981,
[95059]=47983,
[95564]=48100,
[95565]=48101,
[95041]=47976,
[95416]=46686,
[93662]=47256,
[93671]=48014,
[94228]=47716,
[94229]=47715,
[94230]=47718,
[94231]=47717,
[94290]=47825,
[94291]=47826,
[94292]=47828,
[94293]=47827,
[95341]=48020,
--5.3
[98405]=48858,
[98104]=48815,
[98259]=48816,
[97989]=48714,
[98618]=48931,
--5.4
[104327]=51359,
[103638]=51484,
[104246]=51481,
[104253]=51485,
[104269]=51488,
[104325]=51361,
[104326]=51360,
[104208]=51479,
[102514]=51037,
[102533]=51048,
[103630]=17158,
[104011]=51323,
[101675]=49295,
[104329]=51484,
[104346]=51591,
--5.4.1
[106246]=51993,
--5.4.2 PTR
--[107951] Iron Skyreaver(no id)--item
------------------------------------------
--**************************************--
--************* COMPANIONS *************--
--**************************************--
------------------------------------------
--1.11.1 and earlier
[12264]=9563,
[21277]=10269,
[12529]=9997,
[20769]=15436,
[15996]=901,
[11474]=6294,
[11825]=8909,
[11826]=8910,
[10398]=7920,
[11026]=6295,
[11027]=901,
[19450]=14938,
[19462]=14938,
[11023]=5369,
[8499]=6290,
[8500]=4615,
[8501]=6299,
[10360]=1206,
[10361]=2957,
[10392]=6303,
[10393]=2177,
[10394]=1072,
[10822]=6288,
[8498]=6291,
[8494]=6192,
[13582]=10993,
[13583]=10990,
[13584]=10992,
[20371]=15369,
[8485]=5556,
[8486]=5586,
[8487]=5554,
[8488]=5555,
[8489]=9989,
[8490]=5585,
[8491]=5448,
[8492]=5207,
[8495]=6190,
[8496]=6191,
[8497]=328,
[4401]=7937,
[23015]=2176,
[11110]=304,
[21301]=15660,
[21305]=15663,
[21308]=15904,
[23083]=16587,
--22200  Silver Shafted Arrow(not a pet)
[22235]=15992,
[23002]=16259,
[23007]=16257,
[21309]=15671,
--1.12.1
[18964]=14657,
[19054]=14779,
[19055]=14778,
--2.0
[23713]=16943,
--2.0.1
[31760]=20996,
[29363]=19600,
[29364]=4626,
[29902]=19986,
[29958]=20029,
[27445]=18269,
[29901]=19987,
[29903]=19985,
[29904]=19999,
[29953]=20026,
[29956]=20027,
[29957]=20037,
[32588]=21362,
--2.0.3
[23712]=37949,
--2.1
[22114]=15984,
[25535]=17723,
[32616]=21382,
[32617]=21381,
[32622]=21393,
[29960]=20042,
[30360]=15398,
--2.2.2
[32233]=22349,
[33154]=21900,
--2.3
[34478]=22855,
[34535]=6293,
[33993]=22459,
[34493]=22966,
[34425]=22776,
[34492]=22903,
--2.4
[35504]=23574,
[33816]=22388,
[33818]=22389,
[35349]=23507,
[35350]=23506,
--2.4.2
[38628]=25457,
[34955]=8409,
[38050]=25002,
[39656]=25900,
[32498]=21328,
--2.4.3
[37297]=24393,
--3.0.1
[21168]=15595,
[40653]=16633,
--3.0.2
[38658]=4185,
[39973]=28089,
[43698]=27627,
[44723]=28216,
[39896]=28214,
[39899]=28215,
[44721]=28217,
--3.0.3
[39286]=28456,
[44738]=14273,
[39898]=28084,
[44819]=16189,
--3.0.8
[44841]=28397,
--3.1
[44822]=2955,
[45942]=29060,
[44794]=6302,
[44965]=28482,
[44970]=28489,
[44971]=4732,
[44973]=15470,
[44974]=16205,
[44980]=28502,
[44983]=28507,
[44984]=28493,
[44998]=28946,
[45002]=28539,
[45022]=28948,
[45057]=28599,
[45606]=29189,
[44982]=16910,
--3.1.2
[45180]=28734,
--3.1.3
[46767]=29279,
--3.2
[48112]=29805,
[48116]=29803,
[48118]=29802,
[48120]=29809,
[48122]=29810,
[48124]=29808,
[48126]=29806,
[48114]=29807,
[46707]=22629,
[46802]=29348,
[46544]=25384,
[46545]=25173,
[46820]=29372,
[46821]=29372,
[46396]=25384,
[46397]=25173,
--3.2.2
[49362]=30356,
[41133]=26452,
[44810]=21774,
[49665]=30414,
[49693]=30507,
[46831]=29404,
[49287]=30157,
[49343]=30409,
--3.3
[46398]=11709,
[49646]=30462,
[49912]=31174,
[34518]=21304,
[34519]=22938,
[37298]=24620,
[22781]=16189,
[45047]=28811,
--3.3.2
[49662]=30412,
[49663]=30413,
[50446]=31073,
--3.3.3
[53641]=31722,
[54847]=32031,
[54436]=22778,
--3.3.5
[56806]=32670,
--4.0.1
[63138]=37136,
[64403]=33217,
[63398]=36220,
[63355]=36499,
[64996]=36499,
[67128]=32031,
[67418]=36896,
[66076]=9905,
[65362]=37199,
[65363]=37198,
[65364]=37196,
[65661]=32699,
[65662]=32707,
[65361]=37200,
--4.0.3
[60955]=34413,
[46892]=28734,
[49664]=30402,
[62540]=35338,
[62769]=15393,
[48527]=29819,
--68384 Moonkin Egg(contains pet)
--loot changes based on faction
[68385]=37541,
[68618]=37526,
[68619]=37527,
[67600]=6290,
[60847]=34262,
[66080]=28435,
[59597]=33512,
[60216]=33559,
[64372]=36211,
[67274]=36902,
[67275]=36901,
[67282]=37518,
[46325]=29184,
[60869]=33254,
[64494]=36637,
[66067]=37154,
[66073]=38135,
[54810]=31956,
--4.0.6
[68673]=27718,
--4.1
[69991]=22855,
[69824]=38232,
[69821]=38229,
[68840]=30507,
[68841]=37846,
[69648]=38134,
[69847]=38359,
[70099]=16943,
[68833]=37814,
[69239]=37712,
[69992]=29372,
[69251]=38065,
--4.2
[71033]=38614,
[72068]=38359,
[70908]=38539,
[71076]=38638,
[71726]=38803,
[70140]=38455,
[72045]=38342,
[71137]=38691,
[71140]=38693,
[71387]=38776,
[72042]=38343,
[70160]=38429,
--4.3
[73953]=39109,
[71624]=38777,
[72153]=39694,
[73762]=38344,
[73764]=39549,
[73765]=38809,
[73797]=35015,
[73903]=15381,
[73905]=17192,
[72134]=38919,
[74981]=39137,
[76062]=39380,
[78916]=40019,
[75040]=38344,
[75041]=38340,
[75042]=38341,
[74610]=39163,
[74611]=39333,
--4.3.2
[79744]=40538,
--5.0.1
[85513]=43865,
[87526]=45386,
[80008]=45957,
[85220]=44655,
[85222]=46385,
[85447]=47955,
[85578]=45894,
[85871]=43255,
[89587]=41833,
[89686]=45987,
[89736]=45195,
[87567]=44792,
[87568]=44791,
[88148]=43868,
[82774]=15905,
[82775]=42297,
[86562]=43597,
[86563]=45854,
[86564]=45938,
[88147]=43127,
[84105]=42721,
[89367]=44792,
[89368]=44791,
--5.0.4
[90897]=33217,
[90898]=33217,
[90173]=45942,
[90177]=45527,
[90953]=30409,
[90953]=30409,
[90953]=30409,
--5.1
[90900]=44551,
[91040]=46174,
[92707]=46720,
[92798]=46809,
[92799]=46810,
[92800]=46811,
[93031]=46897,
[90902]=40521,
[91031]=46171,
[91003]=46163,
[93029]=46921,
[93025]=46882,
[93032]=46896,
[93033]=46900,
[93034]=46923,
[93035]=46902,
[93036]=46903,
[93037]=46905,
[93038]=46925,
[93039]=46924,
[93040]=46922,
[93041]=46909,
[93030]=46898,
--5.2
[95422]=48055,
[93669]=47348,
[94124]=47848,
[94125]=47252,
[94126]=47731,
[94152]=47708,
[94190]=47732,
[94208]=47747,
[94209]=47749,
[94210]=47748,
[94595]=48091,
[94835]=48001,
[94025]=47634,
[95423]=48056,
[95424]=48057,
[95621]=29279,
[94191]=48211,
[94573]=48213,
[94574]=48212,
[94903]=47711,
[94932]=47959,
[94933]=47957,
[94934]=47958,
[94935]=47960,
--5.3
[98550]=48934,
[100870]=49081,
[97821]=48651,
[97548]=48878,
[97549]=48857,
[97550]=48856,
[97551]=48662,
[97552]=48855,
[97961]=48708,
[97554]=48661,
[97555]=48664,
[97556]=48668,
[97557]=48663,
[97558]=48667,
[97959]=48704,
[97960]=48705,
[97553]=48666,
--5.4
[101570]=855,
[104317]=51505,
[100905]=49084,
[101771]=49846,
[102145]=49835,
[102146]=49845,
[102147]=49836,
[103637]=47858,
[103670]=49289,
[104156]=40908,
[104157]=51413,
[104158]=51268,
[104159]=51271,
[104160]=51408,
[104162]=51417,
[104163]=51267,
[104164]=51270,
[104165]=51269,
[104166]=51272,
[104167]=51279,
[104168]=51278,
[104169]=47991,
[104202]=51475,
[104291]=51502,
[104295]=47856,
[104307]=51504,
[104332]=51530,
[104333]=51530,
[104161]=51277,
--5.4.1
[106240]=51988,
[106244]=51990,
--5.4.2 --PTR
[106256]=51994,
[108438]=37526,
}

---------------------------------------------------------------------------------------------------------------------------------------
--|||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||--
---------------------------------------------------------------------------------------------------------------------------------------

--Spell Data table--
ModelPique_SpellId_Table={
------------------------------------------
--**************************************--
--*************** MOUNTS ***************--
--**************************************--
------------------------------------------
--only spells
[48778]=25280,
[127180]=43708,
[127209]=43709,
[127213]=43710,
[123160]=42837,
[127271]=43713,
[89520]=36022,
[127278]=43716,
[97501]=38032,
[127169]=43697,
[127165]=43695,
[127274]=43714,
[127178]=43707,
[127272]=43715,
[123182]=41089,
--1.11.1 and earlier
[23250]=14573,
[26656]=15676,
[16056]=9695,
[16055]=9991,
[16080]=2326,
[16081]=1166,
[16083]=2410,
[16082]=2408,
[17229]=10426,
[17450]=6471,
[15779]=9474,
[17459]=10666,
[17461]=2784,
[17460]=2787,
[17465]=10720,
[17481]=10718,
[18991]=12245,
[18992]=12242,
[23221]=14331,
[23219]=14332,
[23225]=14374,
[23223]=14376,
[23222]=14377,
[23227]=14582,
[23229]=14583,
[23228]=14338,
[23240]=14346,
[23238]=14347,
[23239]=14576,
[23241]=14339,
[23242]=14344,
[23243]=14342,
[23246]=10721,
[23247]=14349,
[23249]=14578,
[23248]=14579,
[16084]=6469,
[23251]=14575,
[23252]=14574,
[23338]=14632,
[23509]=14776,
[23510]=14777,
[24242]=15289,
[24252]=15290,
[25953]=15672,
[26054]=15681,
[26056]=15679,
[26055]=15680,
[10796]=6472,
[580]=247,
[472]=2409,
[6648]=2405,
[458]=2404,
[6653]=2327,
[6654]=2328,
[6777]=2736,
[6899]=2785,
[6898]=2786,
[10873]=9473,
[8395]=4806,
[470]=2402,
[10799]=6473,
[10969]=6569,
[10793]=6448,
[8394]=6080,
[10789]=6444,
[17453]=10661,
[17454]=9476,
[17462]=10670,
[17463]=10671,
[17464]=10672,
[18989]=12246,
[18990]=11641,
--2.0
[30174]=17158,
--2.0.1
[32246]=17719,
[32296]=17722,
[32297]=17721,
[32295]=17720,
[32235]=17697,
[32239]=17694,
[32240]=17696,
[32243]=17699,
[32244]=17700,
[32245]=17701,
[39316]=21074,
[33660]=18697,
[34896]=19375,
[34897]=19377,
[34898]=19378,
[34899]=19376,
[35025]=19484,
[35027]=19482,
[34896]=19375,
[34790]=19303,
[34898]=19378,
[34899]=19376,
[34897]=19377,
[22719]=14372,
[22718]=14348,
[22720]=14577,
[22717]=14337,
[22724]=14334,
[22722]=10719,
[22723]=14330,
[22721]=14388,
[35713]=19871,
[35712]=19873,
[35714]=19872,
[36702]=19250,
[39315]=21073,
[39315]=21073,
[39317]=21075,
[39317]=21075,
[39318]=21077,
[39318]=21077,
[39319]=21076,
[39319]=21076,
[34406]=17063,
[34795]=18696,
[35020]=19480,
[35022]=19478,
[35018]=19479,
[35711]=19870,
[35710]=19869,
--2.1
[39803]=21156,
[32242]=17759,
[32290]=17703,
[32292]=17717,
[39798]=21152,
[39801]=21155,
[39800]=21158,
[39802]=21157,
[32289]=17718,
[41513]=21520,
[41514]=21521,
[41515]=21525,
[41516]=21523,
[41517]=21522,
[41518]=21524,
[41252]=21473,
--2.1.1
[40192]=17890,
--2.1.2
[37015]=20344,
--2.2
[43900]=22350,
[43899]=22265,
--2.2.2
[42668]=21939,
[42668]=21939,
[42667]=21939,
--2.3
[32345]=17890,
[43688]=22464,
[43927]=22473,
[44151]=22720,
[44744]=22620,
[44153]=22719,
[35028]=20359,
--2.4
[46628]=19483,
[48027]=23928,
--2.4.2
[49193]=24725,
--2.4.3
[58615]=27507,
[49322]=24745,
[49379]=24757,
[48025]=25159,
[58983]=27567,
[47977]=21939,
[66052]=24758,
[66051]=24758,
--3.0.1
[55531]=25871,
[54729]=28108,
--3.0.2
[60424]=25870,
[64749]=17697,
[64762]=17699,
[60002]=28045,
[59567]=27785,
[59571]=27796,
[59570]=25835,
[59569]=25833,
[34061]=22720,
[59568]=25832,
[60025]=25836,
[61309]=28060,
[61229]=27913,
[61230]=27914,
[59650]=25831,
[61451]=28082,
[60118]=27818,
[59785]=27247,
[61470]=27242,
[54753]=28428,
[59788]=27245,
[59797]=27246,
[61469]=27239,
[59799]=27248,
[60119]=27819,
[60114]=27820,
[60116]=27821,
[59791]=27243,
[59793]=27244,
[61447]=27238,
[61425]=27237,
--3.0.3
[59961]=28044,
[61294]=28053,
[61465]=27241,
--3.0.8
[60021]=28042,
--3.0.9
[59976]=28040,
[61467]=27240,
--3.1
[64731]=29161,
[61996]=27525,
[63796]=28890,
[63844]=22471,
[61997]=28402,
[34492]=22903,
[63636]=29258,
[63638]=28571,
[63639]=29255,
[63637]=29256,
[63641]=29259,
[63635]=29261,
[63640]=29260,
[63642]=29262,
[63643]=29257,
[64656]=10718,
[64658]=207,
[64657]=12241,
[64977]=29130,
--3.1.1
[65439]=25593,
--3.1.2
[63963]=28954,
[65640]=29043,
[65638]=14333,
[65637]=28606,
[65645]=28605,
[65644]=14343,
[65643]=28612,
[65646]=14335,
[65641]=28556,
[65639]=28607,
[65642]=14375,
--3.1.3
[63956]=28953,
--3.2
[60024]=28043,
[66087]=22474,
[66088]=29696,
[46199]=23647,
[64927]=25511,
[46197]=23656,
[64659]=29102,
[66090]=28888,
[66091]=28889,
[66846]=29754,
[66906]=28919,
[67466]=28918,
[68057]=29284,
[68187]=29937,
[68188]=29938,
[51412]=25335,
[42777]=21974,
[65917]=29344,
[66847]=29755,
[42776]=21973,
--3.2.2
[69395]=30346,
[68056]=29283,
[68769]=30141,
[68768]=30518,
--3.3
[72286]=31007,
--3.3.2
[72808]=31156,
[71342]=30989,
--3.3.3
[67336]=29794,
[72807]=31154,
[75596]=28063,
[74856]=31803,
[75973]=31992,
[73313]=25279,
[75614]=31958,
--3.3.5
[74918]=31721,
--4.0.1
[93326]=35750,
[88746]=35751,
[88331]=35551,
[88335]=35757,
[88741]=35754,
[88742]=35553,
[88744]=35755,
[88718]=35740,
[71810]=31047,
[88990]=37145,
[92231]=37160,
[92232]=37159,
[88741]=35754,
[88748]=35136,
[88749]=35134,
[88750]=35135,
[92155]=15672,
--4.0.3
[98718]=34955,
[75207]=34956,
[93623]=37231,
[84751]=34410,
[87091]=35250,
[90621]=36213,
[93644]=37138,
[87090]=35249,
--4.1
[98204]=38261,
[97359]=38018,
[97493]=38031,
[96503]=37800,
[96491]=14341,
[96499]=37799,
[97581]=38048,
[98727]=38260,
--4.2
[97560]=38046,
[101282]=38756,
[100332]=38668,
[100333]=38607,
[101542]=38783,
--4.3
[107842]=39561,
[107845]=39563,
[110039]=39229,
[107844]=39562,
[101821]=38755,
[74856]=31803,
[107516]=39546,
[107517]=39547,
[103196]=39095,
[101573]=17011,
[102346]=1281,
[102349]=16992,
[102350]=1961,
[102488]=37204,
[103081]=39060,
[107203]=39530,
[110051]=40029,
[103195]=39096,
--4.3.2
[113120]=40568,
--5.0.1
[121837]=42502,
[113199]=40590,
[120043]=42185,
[122708]=42703,
[123993]=41991,
[123992]=41989,
[127154]=41990,
[127156]=41592,
[127158]=43689,
[127161]=43692,
[127164]=43693,
[127170]=46087,
[127174]=43704,
[127176]=43705,
[127177]=43706,
[127216]=43711,
[127220]=43712,
[129552]=44633,
[129918]=43686,
[129932]=44759,
[129935]=44757,
[129934]=43900,
[130086]=44807,
[130137]=44837,
[130138]=44836,
[130965]=45264,
[121838]=42499,
[118089]=41711,
[121839]=42501,
[121836]=42500,
[118737]=41903,
[124408]=43562,
[130985]=45271,
[123886]=43090,
[121820]=42498,
[126507]=43637,
[126508]=43638,
[130092]=44808,
[120822]=42352,
[127293]=43722,
[127295]=43723,
[127302]=43724,
[127308]=43725,
[127310]=43726,
[124659]=43254,
[120395]=42250,
[127286]=43717,
[127287]=43718,
[127288]=43719,
[127289]=43720,
[127290]=43721,
[130678]=44635,
[130730]=45163,
[130895]=45242,
--5.0.4
[132036]=45797,
[132118]=45520,
[132119]=45522,
[132117]=45521,
[120822]=42352,
[127295]=43723,
[127293]=43722,
[127302]=43724,
[127308]=43725,
[127310]=43726,
[120395]=42250,
[127288]=43719,
[127289]=43720,
[127290]=43721,
[127286]=43717,
[127287]=43718,
--5.0.5
[124550]=38757,
--5.1
[135416]=46929,
[135418]=46930,
[136163]=47166,
[136164]=47165,
[133023]=42147,
[134573]=46729,
--5.2
[136471]=47238,
[139442]=47981,
[139448]=47983,
[140249]=48100,
[140250]=48101,
[139407]=47976,
[134359]=46686,
[136400]=47256,
[136505]=48014,
[138423]=47716,
[138425]=47715,
[138424]=47718,
[138426]=47717,
[138640]=47825,
[138641]=47826,
[138642]=47828,
[138643]=47827,
[139595]=48020,
--5.3
[142641]=48858,
[142266]=48815,
[142478]=48816,
[142878]=48714,
[142073]=48931,
--5.4
[148620]=51359,
[148428]=51484,
[148396]=51481,
[148417]=51485,
[148476]=51488,
[148618]=51361,
[148619]=51360,
[148392]=51479,
[146615]=51037,
[146622]=51048,
[30174]=17158,
[147595]=51323,
[145133]=49295,
[148626]=51484,
[148773]=51591,
--5.4.1
[149801]=51993,
--5.4.2 PTR
--[153489] Iron Skyreaver(no id)--spell
------------------------------------------
--**************************************--
--************* COMPANIONS *************--
--**************************************--
------------------------------------------
--spells only
[66520]=29605,
[40319]=21304,
[93815]=38311,
[93461]=32031,
[93818]=36583,
[75936]=28734,
[89929]=36129,
[89930]=36130,
[89931]=36131,
[148068]=51742,
[143732]=49086,
[148069]=51301,
[123214]=42872,
[123212]=32790,
[148065]=51740,
[89929]=36129,
[89930]=36130,
[89931]=36131,
--1.11.1 and earlier
[15999]=9563,
[26010]=10269,
[16450]=9997,
[25162]=15436,
[19772]=901,
[15067]=6294,
[15048]=8909,
[15049]=8910,
[12243]=7920,
[10704]=6295,
[10703]=901,
[23811]=14938,
[23851]=14938,
[10685]=5369,
[10697]=6290,
[10707]=4615,
[10706]=6299,
[10714]=1206,
[10716]=2957,
[10717]=6303,
[10688]=2177,
[10709]=1072,
[10695]=6288,
[10698]=6291,
[10682]=6192,
[17709]=10993,
[17707]=10990,
[17708]=10992,
[24696]=15369,
[10673]=5556,
[10674]=5586,
[10676]=5554,
[10678]=5555,
[10679]=9989,
[10677]=5585,
[10675]=5448,
[10683]=5207,
[10684]=6190,
[10680]=6191,
[10711]=328,
[4055]=7937,
[28740]=2176,
[13548]=304,
[26533]=15660,
[26541]=15663,
[26529]=15904,
[28871]=16587,
[27570]=15992,
[28738]=16259,
[28739]=16257,
[26045]=15671,
--1.12.1
[23429]=14657,
[23530]=14779,
[23531]=14778,
--2.0
[30156]=16943,
--2.0.1
[39181]=20996,
[35156]=19600,
[35239]=4626,
[35909]=19986,
[36031]=20029,
[33050]=18269,
[35907]=19987,
[35910]=19985,
[35911]=19999,
[36027]=20026,
[36028]=20027,
[36029]=20037,
[40549]=21362,
--2.0.3
[30152]=37949,
--2.1
[27241]=15984,
[32298]=17723,
[40614]=21382,
[40613]=21381,
[40634]=21393,
[36034]=20042,
[24988]=15398,
--2.2.2
[39709]=22349,
[42609]=21900,
--2.3
[45082]=22855,
[10696]=6293,
[43918]=22459,
[45127]=22966,
[54187]=22776,
[45125]=22903,
--2.4
[46599]=23574,
[43697]=22388,
[43698]=22389,
[46425]=23507,
[46426]=23506,
--2.4.2
[51716]=25457,
[45890]=8409,
[49964]=25002,
[53082]=25900,
[40405]=21328,
--2.4.3
[48406]=24393,
--3.0.1
[25849]=15595,
[40990]=16633,
--3.0.2
[51851]=4185,
[53316]=28089,
[59250]=27627,
[61357]=28216,
[61348]=28214,
[61349]=28215,
[61350]=28217,
--3.0.3
[52615]=28456,
[61472]=14273,
[61351]=28084,
[61855]=16189,
--3.0.8
[61991]=28397,
--3.1
[10713]=2955,
[64351]=29060,
[61725]=6302,
[62491]=28482,
[62508]=28489,
[62510]=4732,
[62513]=15470,
[62516]=16205,
[62542]=28502,
[62561]=28507,
[62562]=28493,
[62609]=28946,
[62674]=28539,
[62746]=28948,
[62949]=28599,
[63712]=29189,
[62564]=16910,
--3.1.2
[63318]=28734,
--3.1.3
[65682]=29279,
--3.2
[67413]=29805,
[67415]=29803,
[67416]=29802,
[67417]=29809,
[67418]=29810,
[67419]=29808,
[67420]=29806,
[67414]=29807,
[44369]=22629,
[66030]=29348,
[65382]=25384,
[65381]=25173,
[66096]=29372,
[66096]=29372,
[65353]=25384,
[65352]=25173,
--3.2.2
[69002]=30356,
[55068]=26452,
[61773]=21774,
[69541]=30414,
[69677]=30507,
[66175]=29404,
[68767]=30157,
[68810]=30409,
--3.3
[65358]=11709,
[69452]=30462,
[70613]=31174,
[45174]=21304,
[45175]=22938,
[48408]=24620,
[28505]=16189,
[62857]=28811,
--3.3.2
[69535]=30412,
[69536]=30413,
[71840]=31073,
--3.3.3
[74932]=31722,
[75906]=32031,
[75134]=22778,
--3.3.5
[78381]=32670,
--4.0.1
[89039]=37136,
[90637]=33217,
[89670]=36220,
[89472]=36499,
[89472]=36499,
[93624]=32031,
[94070]=36896,
[93739]=9905,
[92396]=37199,
[92397]=37198,
[92398]=37196,
[78683]=32699,
[78685]=32707,
[92395]=37200,
--4.0.3
[84752]=34413,
[63318]=28734,
[69539]=30402,
[87344]=35338,
[87863]=15393,
[67527]=29819,
[95787]=37541,
[95786]=37526,
[95909]=37527,
[94716]=6290,
[84263]=34262,
[93813]=28435,
[81937]=33512,
[82173]=33559,
[90523]=36211,
[93836]=36902,
[93837]=36901,
[93838]=37518,
[65046]=29184,
[84492]=33254,
[91343]=36637,
[93823]=37154,
[93817]=38135,
[75613]=31956,
--4.0.6
[16450]=27718,
--4.1
[45082]=22855,
[98587]=38232,
[98571]=38229,
[96817]=30507,
[96819]=37846,
[98079]=38134,
[98736]=38359,
[99578]=16943,
[96571]=37814,
[97638]=37712,
[66096]=29372,
[97779]=38065,
--4.2
[100576]=38614,
[98736]=38359,
[100330]=38539,
[100684]=38638,
[101606]=38803,
[99663]=38455,
[101989]=38342,
[100959]=38691,
[100970]=38693,
[101424]=38776,
[101986]=38343,
[99668]=38429,
--4.3
[103588]=39109,
[101493]=38777,
[102353]=39694,
[103076]=38344,
[101733]=39549,
[103074]=38809,
[103125]=35015,
[103544]=15381,
[103549]=17192,
[102317]=38919,
[105122]=39137,
[105633]=39380,
[110029]=40019,
[140218]=38344,
[105228]=38340,
[105229]=38341,
[104047]=39163,
[104049]=39333,
--4.3.2
[112994]=40538,
--5.0.1
[127813]=43865,
[126885]=45386,
[114090]=45957,
[123778]=44655,
[123784]=46385,
[124000]=47955,
[124152]=45894,
[124660]=43255,
[118414]=41833,
[130726]=45987,
[130759]=45195,
[127006]=44792,
[127008]=44791,
[127816]=43868,
[120501]=15905,
[120507]=42297,
[126247]=43597,
[126249]=45854,
[126251]=45938,
[127815]=43127,
[122748]=42721,
[127006]=44792,
[127008]=44791,
--5.0.4
[90637]=33217,
[90637]=33217,
[131590]=45942,
[131650]=45527,
[68810]=30409,
[132759]=30409,
[49343]=30409,
--5.1
[132574]=44551,
[132789]=46174,
[134538]=46720,
[134892]=46809,
[134894]=46810,
[134895]=46811,
[135256]=46897,
[132580]=40521,
[132785]=46171,
[132762]=46163,
[135257]=46921,
[135156]=46882,
[135255]=46896,
[135258]=46900,
[135259]=46923,
[135261]=46902,
[135263]=46903,
[135265]=46905,
[135264]=46925,
[135266]=46924,
[135267]=46922,
[135268]=46909,
[135254]=46898,
--5.2
[139932]=48055,
[136484]=47348,
[138082]=47848,
[137977]=47252,
[138087]=47731,
[138161]=47708,
[138285]=47732,
[138380]=47747,
[138381]=47749,
[138382]=47748,
[138913]=48091,
[139148]=48001,
[137568]=47634,
[139933]=48056,
[139934]=48057,
[65682]=29279,
[138287]=48211,
[139153]=48213,
[138825]=48212,
[138824]=47711,
[139361]=47959,
[139362]=47957,
[139363]=47958,
[139365]=47960,
--5.3
[142880]=48934,
[143637]=49081,
[141789]=48651,
[141433]=48878,
[141434]=48857,
[141435]=48856,
[141451]=48662,
[141436]=48855,
[142030]=48708,
[141446]=48661,
[141447]=48664,
[141448]=48668,
[141449]=48663,
[141450]=48667,
[142028]=48704,
[142029]=48705,
[141437]=48666,
--5.4
[144761]=855,
[148567]=51505,
[143703]=49084,
[145696]=49846,
[145697]=49835,
[145699]=49845,
[145698]=49836,
[148427]=47858,
[147124]=49289,
[148046]=40908,
[148047]=51413,
[148049]=51268,
[148050]=51271,
[148051]=51408,
[148058]=51417,
[148059]=51267,
[148060]=51270,
[148061]=51269,
[148062]=51272,
[148063]=51279,
[148066]=51278,
[148067]=47991,
[148373]=51475,
[148527]=51502,
[148530]=47856,
[148552]=51504,
[148684]=51530,
[148052]=51277,
--5.4.1
[149787]=51988,
[149792]=51990,
--5.4.2 --PTR
[149810]=51994,
[154165]=37526,
}

---------------------------------------------------------------------------------------------------------------------------------------
--|||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||--
---------------------------------------------------------------------------------------------------------------------------------------

--Battle Pet Data Table--
ModelPique_BattlePetId_Table={
--Player ownable 5.4.2 and earlier
[39]=7937,
[40]=5556,
[41]=5586,
[42]=5448,
[43]=5554,
[44]=5585,
[45]=5555,
[46]=9990,
[47]=6191,
[49]=6192,
[50]=5207,
[51]=6190,
[52]=5369,
[55]=2177,
[56]=6288,
[57]=6293,
[58]=6290,
[59]=6291,
[255]=31956,
[511]=35804,
[64]=901,
[128]=16587,
[256]=32031,
[512]=35113,
[513]=42523,
[514]=42553,
[258]=32670,
[517]=45998,
[259]=32699,
[518]=42575,
[65]=6295,
[519]=45923,
[260]=32707,
[1039]=44551,
[1040]=40521,
[521]=45988,
[261]=33512,
[131]=17723,
[262]=33559,
[525]=45968,
[132]=18269,
[264]=34262,
[528]=45953,
[529]=42617,
[265]=45940,
[530]=42781,
[1062]=46171,
[1063]=46174,
[267]=36902,
[534]=42709,
[67]=6299,
[535]=30159,
[268]=35338,
[536]=25390,
[537]=42735,
[538]=42737,
[539]=4959,
[270]=37136,
[540]=1141,
[541]=2177,
[271]=36499,
[542]=6297,
[68]=4615,
[543]=2177,
[272]=36220,
[544]=36944,
[545]=15469,
[546]=42771,
[137]=4626,
[548]=30412,
[549]=45900,
[550]=4959,
[69]=6298,
[138]=19987,
[552]=42783,
[553]=1141,
[277]=36211,
[554]=36605,
[139]=19986,
[278]=33217,
[556]=15467,
[557]=42467,
[279]=36637,
[558]=42757,
[70]=1072,
[140]=19985,
[280]=37200,
[560]=45995,
[281]=37199,
[562]=36544,
[1124]=46809,
[141]=19999,
[282]=37198,
[564]=27883,
[1128]=40714,
[565]=6297,
[283]=37196,
[566]=45852,
[142]=20026,
[568]=38380,
[569]=38831,
[285]=32031,
[570]=40093,
[143]=20027,
[286]=9905,
[1143]=46898,
[1144]=46896,
[1145]=46897,
[1146]=46921,
[1147]=46900,
[72]=328,
[144]=20037,
[1150]=46902,
[1151]=46903,
[1152]=46925,
[1153]=46905,
[289]=38135,
[1155]=46922,
[1156]=46909,
[145]=20029,
[1159]=46938,
[1160]=46941,
[1161]=47636,
[291]=37154,
[1163]=46948,
[1164]=47021,
[146]=20042,
[1166]=46953,
[1167]=46954,
[1168]=15395,
[293]=45878,
[294]=36896,
[1175]=47633,
[1176]=47634,
[1177]=47252,
[1178]=47848,
[1179]=47690,
[74]=2955,
[1181]=47887,
[296]=37526,
[1183]=47708,
[1184]=48211,
[1185]=47732,
[297]=37541,
[149]=20996,
[298]=37527,
[75]=1206,
[1197]=47749,
[1198]=47748,
[1200]=48212,
[1201]=48091,
[301]=37814,
[1204]=47711,
[1205]=48213,
[302]=30507,
[1207]=47957,
[1208]=47958,
[1209]=47960,
[303]=37846,
[1211]=48055,
[1212]=48056,
[1213]=48057,
[153]=22349,
[306]=37712,
[307]=38065,
[1227]=48857,
[77]=2957,
[1229]=48662,
[308]=38134,
[1231]=48666,
[1232]=48661,
[1233]=48664,
[1234]=48668,
[1235]=48663,
[1236]=48667,
[1237]=48651,
[310]=38232,
[311]=38359,
[1243]=48704,
[78]=6303,
[156]=21362,
[1248]=48934,
[626]=4732,
[627]=10090,
[628]=37686,
[1256]=49084,
[629]=32790,
[630]=42872,
[158]=21382,
[316]=16943,
[632]=36583,
[633]=16633,
[317]=38455,
[634]=45909,
[159]=21393,
[318]=38429,
[637]=20923,
[319]=38539,
[638]=2177,
[1276]=855,
[160]=16633,
[320]=38614,
[640]=328,
[641]=328,
[321]=38638,
[644]=22175,
[645]=45970,
[323]=38693,
[646]=304,
[647]=134,
[648]=5379,
[649]=1924,
[325]=38776,
[650]=44655,
[163]=22388,
[652]=47955,
[1304]=49836,
[1305]=49845,
[164]=22389,
[328]=38777,
[329]=38803,
[165]=22459,
[330]=46001,
[1320]=49289,
[1321]=51413,
[331]=38343,
[1323]=40908,
[83]=7920,
[166]=22629,
[332]=38342,
[1328]=51271,
[665]=39694,
[333]=38919,
[1331]=51417,
[1332]=51267,
[167]=22855,
[1335]=51272,
[1336]=51279,
[1337]=51278,
[335]=38809,
[84]=304,
[168]=22903,
[336]=38344,
[1343]=51475,
[1344]=47858,
[1345]=51502,
[337]=45939,
[1348]=51504,
[169]=22966,
[338]=15381,
[1351]=29404,
[677]=40089,
[339]=17192,
[678]=40226,
[85]=8909,
[170]=21304,
[340]=39109,
[680]=43347,
[341]=39163,
[1363]=51988,
[1364]=51990,
[171]=22938,
[342]=39333,
[343]=39137,
[86]=8910,
[172]=8409,
[173]=23507,
[346]=39380,
[347]=40019,
[87]=6294,
[174]=23506,
[348]=40538,
[175]=23574,
[702]=6296,
[706]=40089,
[708]=45991,
[709]=45990,
[710]=43360,
[89]=9563,
[711]=42856,
[712]=42983,
[713]=27679,
[714]=44816,
[179]=24393,
[716]=45910,
[717]=45996,
[718]=36955,
[90]=27718,
[180]=24620,
[722]=28434,
[723]=42859,
[724]=36388,
[725]=42757,
[726]=45999,
[728]=304,
[729]=6302,
[730]=28998,
[183]=25002,
[732]=36956,
[733]=43344,
[92]=10990,
[737]=43347,
[740]=4959,
[741]=45984,
[742]=45985,
[93]=10992,
[186]=25457,
[744]=45898,
[745]=15469,
[746]=45881,
[187]=4185,
[374]=42906,
[748]=36956,
[749]=43428,
[750]=43259,
[94]=10993,
[188]=28456,
[752]=6297,
[753]=36671,
[754]=20042,
[755]=2177,
[378]=328,
[756]=36944,
[757]=14778,
[379]=134,
[758]=14779,
[95]=901,
[190]=28089,
[380]=40713,
[381]=41833,
[191]=22776,
[383]=43798,
[192]=26452,
[385]=4959,
[193]=27627,
[386]=1072,
[387]=1206,
[194]=45919,
[388]=45880,
[389]=41886,
[195]=28215,
[391]=328,
[196]=28217,
[392]=1141,
[393]=2177,
[197]=28084,
[395]=41887,
[198]=28216,
[396]=2536,
[792]=43868,
[397]=16633,
[199]=45937,
[398]=1141,
[399]=3126,
[200]=6302,
[400]=45905,
[401]=32789,
[802]=43865,
[201]=45968,
[402]=36944,
[403]=6189,
[202]=16189,
[404]=4959,
[405]=36578,
[203]=28397,
[406]=7511,
[407]=45902,
[204]=28482,
[408]=36583,
[817]=43875,
[409]=42509,
[818]=45064,
[205]=28489,
[410]=1141,
[820]=43127,
[821]=45894,
[411]=21362,
[206]=4732,
[412]=45902,
[207]=15470,
[414]=15469,
[415]=8971,
[416]=41960,
[417]=1141,
[834]=45938,
[209]=16205,
[418]=1986,
[836]=45854,
[837]=36603,
[419]=6297,
[838]=36604,
[210]=28502,
[420]=901,
[421]=36671,
[211]=45880,
[422]=1986,
[844]=45386,
[845]=15905,
[423]=28507,
[846]=42297,
[106]=14938,
[212]=28493,
[424]=2177,
[848]=45957,
[849]=44791,
[425]=4268,
[850]=44792,
[213]=45960,
[427]=45904,
[107]=15369,
[214]=28946,
[428]=42051,
[856]=45987,
[429]=41981,
[215]=28539,
[430]=15467,
[431]=35804,
[216]=28948,
[432]=15469,
[433]=36585,
[217]=28734,
[868]=45942,
[218]=46939,
[437]=42068,
[438]=2954,
[439]=45917,
[220]=45943,
[440]=42203,
[441]=36342,
[442]=2177,
[443]=328,
[111]=15398,
[445]=45936,
[446]=42218,
[447]=654,
[224]=11709,
[448]=1560,
[449]=45899,
[225]=25173,
[450]=9904,
[903]=45527,
[452]=36620,
[453]=42229,
[227]=29279,
[454]=1141,
[455]=42334,
[114]=15436,
[228]=29348,
[456]=42265,
[457]=9904,
[229]=29372,
[458]=45952,
[459]=5585,
[460]=42335,
[461]=9906,
[231]=29605,
[463]=42342,
[116]=10269,
[232]=29805,
[464]=42343,
[465]=42344,
[233]=29807,
[466]=36583,
[467]=7511,
[117]=13610,
[234]=29803,
[468]=46940,
[469]=36644,
[235]=29802,
[470]=36236,
[471]=7920,
[731]=4440,
[118]=15904,
[236]=29809,
[472]=26532,
[1266]=49846,
[157]=21381,
[287]=28435,
[473]=27881,
[1073]=15398,
[567]=2955,
[237]=29810,
[474]=42362,
[679]=43485,
[1326]=51740,
[162]=21900,
[475]=45896,
[573]=45994,
[119]=15660,
[238]=29808,
[1349]=51505,
[226]=25384,
[1042]=46385,
[477]=45958,
[743]=45882,
[309]=38229,
[239]=29806,
[478]=36944,
[1142]=46882,
[189]=25900,
[136]=19600,
[479]=328,
[292]=36901,
[120]=15663,
[240]=29819,
[480]=36648,
[155]=21328,
[130]=16943,
[266]=34413,
[847]=42721,
[1245]=48708,
[631]=36578,
[241]=30157,
[482]=4268,
[635]=1986,
[515]=42554,
[483]=36583,
[1228]=48856,
[121]=15984,
[242]=30409,
[484]=45906,
[523]=45885,
[1303]=49835,
[485]=42381,
[532]=42708,
[835]=43597,
[243]=30356,
[1061]=46163,
[751]=40584,
[487]=36620,
[1322]=51268,
[122]=15992,
[244]=30462,
[488]=36580,
[855]=45195,
[819]=43874,
[1324]=51742,
[489]=42745,
[1325]=51301,
[1230]=48855,
[245]=30412,
[1329]=51408,
[1330]=51277,
[1202]=48001,
[491]=5586,
[727]=4959,
[246]=30413,
[492]=7511,
[1333]=51270,
[1334]=51269,
[1338]=47991,
[493]=42407,
[671]=43255,
[1346]=47856,
[247]=30402,
[494]=42416,
[1162]=46947,
[1158]=46937,
[547]=45820,
[495]=6297,
[1350]=51530,
[124]=16189,
[248]=30414,
[496]=42409,
[555]=45897,
[1365]=51994,
[559]=45879,
[497]=2177,
[1117]=46720,
[1125]=46810,
[249]=30507,
[498]=36944,
[699]=45911,
[1127]=30409,
[823]=22447,
[499]=1141,
[571]=35802,
[125]=16259,
[250]=31174,
[500]=46003,
[703]=43194,
[1149]=46923,
[1154]=46924,
[707]=41834,
[1157]=46936,
[251]=31073,
[502]=6297,
[1165]=47635,
[1174]=47348,
[1182]=47989,
[503]=36944,
[851]=36583,
[126]=16257,
[504]=45913,
[1206]=47959,
[739]=43346,
[1226]=48878,
[505]=42415,
[747]=46000,
[1238]=48650,
[253]=31722,
[506]=45908,
[1126]=46811,
[1013]=44779,
[507]=6300,
[572]=45880,
[127]=2176,
[254]=22778,
[508]=42412,
[675]=1141,
[639]=1072,
[1244]=48705,
[509]=42202,
[1196]=47747,
[1180]=47731,
[1068]=36743,
}